import { 
    select, 
    csv, 
    scaleLinear, 
    max, 
    scaleBand, 
    axisLeft,
    axisBottom,
  	format
} from 'd3'

const svg = select('svg')
const height = +svg.attr('height');//parseFloat
const width = +svg.attr('width');

const render = data=> {
    const xValue = d => d.population;
    const yValue = d => d.country;
    const margin={top: 50, right: 40, bottom: 75, left: 180};
    const innerwidth= width-margin.left-margin.right;
    const innerheight= height-margin.top-margin.bottom;

    const xScale = scaleLinear()
        .domain([0, max(data, xValue)])
        .range([0, innerwidth]);

    const yScale = scaleBand()
        .domain(data.map(yValue))
        .range([0, innerheight])
        .padding(0.1);

//the margin convention
    const g = svg.append('g')
        .attr('transform', `translate(${margin.left},${margin.top})`);
  	const xAxisTickFormat = number => 
    	format('.3s')(number)
    		.replace('G','B');
  	const xAxis = axisBottom(xScale)
    		.tickSize(-innerheight)
    		.tickFormat(xAxisTickFormat);
  
  
    //adding axis
    g.append('g')
      .call(axisLeft(yScale))
  		.selectAll('.domain, .tick line')//selectAll can choose more than one thing comparing with the select
  			.remove();//remove unnecessary lines
  
    const xAxisG = g.append('g').call(xAxis)
        .attr('transform', `translate(0,${innerheight})`);
  	xAxisG.select('.domain').remove();
  	xAxisG.append('text')
  		.attr('class','axis-label')
  		.attr('y',65)
  		.attr('x',innerwidth/2)
  		.attr('fill','black')
  		.text('population');

    g.selectAll('rect').data(data)//create a D3 data join
     .enter().append('rect')
     .attr('y', d=> yScale(yValue(d)))
  	 .attr('width',d => xScale(xValue(d)))
  	 .attr('height',yScale.bandwidth());
  
  	g.append('text')
  		.attr('class','title-label')
  		.attr('y', -10)
  		.text('Top 10 Most populous Countries');
};

csv('data.csv').then(data => {
  	data.forEach(d=>{
    	d.population = +d.population * 1000;//make the population become numbers
    });
    render(data);
});